pub trait ToolkitSession<TCtx>: Send + Sync {
// Required methods
fn system_prompt(&self) -> Option<String>;
fn tools(&self) -> Vec<Arc<dyn AgentTool<TCtx>>>;
fn close(self: Box<Self>) -> BoxFuture<'static, Result<(), BoxedError>>;
}Expand description
ToolkitSession exposes dynamically resolved tools and system prompt data
for a run session.
Required Methods
Sourcefn system_prompt(&self) -> Option<String>
fn system_prompt(&self) -> Option<String>
Retrieve the current system prompt for the session, if available.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".